
from datetime import datetime, timedelta

import matplotlib.dates as mdates
import matplotlib.pyplot as plt
import numpy as np
import pandas
import xarray
import scipy.ndimage as ndi

def plot_emission_heights(filename, name='JAE', do_diurnal=False):
    """
    Plot time series of emission heights (annual or diurnal).
    """
    d = xarray.open_dataset(filename)

    # find index for id/name
    for i,s in enumerate(np.array(d.id, str)):
        if s == name:
            break

    H = d.H[i]
    h = np.array(d.h_ts)[i]
    h30 = ndi.convolve(h, np.ones(720)/720.0)
    times = [datetime(2015,1,1) + timedelta(hours=hour) for hour in
             range(24*365)]

    ts = pandas.Series(h, times)

    fig = plt.figure()
    ax = fig.add_subplot(111)

    if do_diurnal:
        hours = np.arange(24)
        heights = [np.mean(ts[ts.index.hour == hour]) for hour in hours]

        ax.plot(hours, heights)
        ax.set_xlabel('hour of day (UTC)')
        ax.set_xlim(0,23)
        ax.set_xticks(np.arange(0,24,3))

    else:
        ax.plot(ts.index, ts, label='hourly')
        ax.plot(times, h30, label='30-day mean')
        ax.plot([times[0], times[-1]], [H,H], 'k-', label='stack height')

        ax.xaxis.set_major_formatter(mdates.DateFormatter('%b'))

        ax.set_ylim(0,2000)
        ax.set_xlabel('2015')
        plt.legend()

    ax.set_ylabel('height (m)')
    plt.tight_layout()


